# -*- coding: utf-8
from __future__ import unicode_literals

from fragments.commands import _main


if __name__ == '__main__': # pragma: no cover
    _main()
